import org.openqa.selenium.WebDriver;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.support.FindBy;
import org.openqa.selenium.support.How;
import org.openqa.selenium.support.PageFactory;
import org.openqa.selenium.support.ui.ExpectedCondition;
import org.openqa.selenium.support.ui.ExpectedConditions;
import org.openqa.selenium.support.ui.WebDriverWait;
import sun.security.util.Password;

import java.util.concurrent.TimeUnit;

public class LoginPF {
    WebDriver driver;
    WebDriverWait wdw;

    @FindBy(how = How.PARTIAL_LINK_TEXT, using = "Sign In / Up")
    WebElement expandLoginOptionsButton;

    @FindBy(how = How.ID, using = "sign-in-modal-link")
    WebElement revealLoginModalButton;

    @FindBy(how = How.ID, using = "label-email")
    WebElement userNameInputBox;

    @FindBy(how = How.ID, using = "label-password")
    WebElement userPasswordInputBox;

    @FindBy(how = How.ID, using = "btnSignIn")
    WebElement signInButton;

    public LoginPF(WebDriver driver) {
        this.driver = driver;
        this.wdw = new WebDriverWait(this.driver, 1);
        PageFactory.initElements(driver, this);
    }

    public void revealLoginModal() {
        wdw.until(ExpectedConditions.elementToBeClickable(expandLoginOptionsButton));
        expandLoginOptionsButton.click();
        wdw.until(ExpectedConditions.elementToBeClickable(revealLoginModalButton));
        revealLoginModalButton.click();
    }

    public void fillUserInfo(String userName, String password) {
        wdw.until(ExpectedConditions.elementToBeClickable(userNameInputBox));
        wdw.until(ExpectedConditions.elementToBeClickable(userPasswordInputBox));
        this.userNameInputBox.sendKeys(userName);
        this.userPasswordInputBox.sendKeys(password);
    }

    public void login(String username, String password) {
        revealLoginModal();
        fillUserInfo(username, password);
        wdw.until(ExpectedConditions.elementToBeClickable(signInButton));
        signInButton.click();
    }

}
